@@ -1,4 +1,5 @@
-from os import listdir, path
+from posix import listdir
+from posixpath import dirname, splitext
 from inspect import getmembers, getmodule, isclass
 
 
@@ -18,8 +19,8 @@ class Core(Object):
         self.parent = runtime.find("Object")
 
     def load_objects(self):
-        for filename in listdir(path.dirname(__file__)):
-            name, ext = path.splitext(filename)
+        for filename in listdir(dirname(__file__)):
+            name, ext = splitext(filename)
             if ext == ".py" and name != "__init__":
                 module = __import__("mio.core.{0:s}".format(name), fromlist=["mio.core"])
                 predicate = lambda x: isclass(x) and issubclass(x, Object) and getmodule(x) is module and x is not Core
