@@ -11,6 +11,9 @@ class List(Object):
         self.create_methods()
         self.parent = runtime.find("Object")
 
+    def __hash__(self):
+        return None
+
     def __len__(self):
         return len(self.value)
 
@@ -18,10 +21,7 @@ class List(Object):
         return iter(self.value) if isinstance(self.value, list) else iter([])
 
     def __repr__(self):
-        if isinstance(self.value, list):
-            values = ", ".join([repr(item) for item in self.value])
-            return "[{0:s}]".format(values)
-        return "[]"
+        return repr(self.value)
 
     @method()
     def init(self, receiver, context, m, iterable=None):
