@@ -6,7 +6,7 @@ try:
 except ImportError:
     HAS_COVERAGE = False
 
-from mio.main import main
+from mio.main import entrypoint
 
 
 if __name__ == "__main__":
@@ -14,8 +14,7 @@ if __name__ == "__main__":
         if HAS_COVERAGE:
             _coverage = coverage(data_suffix=True)
             _coverage.start()
-        import sys
-        main(sys.argv[1:])
+        entrypoint()
     finally:
         if HAS_COVERAGE:
             _coverage.stop()
